@@ -58,6 +58,7 @@ except ImportError:
 
 import urllib.request
 from xml.etree.ElementTree import ElementTree
+from xml.etree.ElementTree import ParseError
 from xml.parsers.expat import ExpatError
 
 if platform.system() == 'Windows':
@@ -319,6 +320,10 @@ class Config:
         if url != None:
             name = self._get_name_from_url(url)
         if name != None and self._config.has_section(name):
+            if state == True:
+                state = 'True'
+            elif state == False:
+                 state = 'False'
             self._config.set(name, "active", state)
             self.save()
             return name
@@ -408,7 +413,10 @@ class Config:
         sections.sort()
         for section in sections:
             self._config.remove_section(section)
-            self._config._sections[section] = old[section]
+            self._config.add_section(section)
+            for option in old[section]:
+                value = old[section][option]
+                self._config.set(section, option, value)
 
     def download_directory(self, directory=None):
         """
@@ -586,7 +594,13 @@ class FeedReader(threading.Thread):
         return self._urls
 
     def log(self, text):
-        pass
+        """
+        Log
+
+        @type   text:   string
+        @param  text:   string to log
+        """
+        print("IIII %s" % text)
 
     @staticmethod
     def parse_feed(tree:ElementTree):
@@ -676,6 +690,8 @@ class FeedReader(threading.Thread):
             self.log("KeyError: %s, unknown keys %s" % (self._url, error.args))
         except ExpatError as error:
             self.log("ExpatError: %s (%s)" % (self._url, error.code))
+        except ParseError as error:
+            self.log("ParseError: %s (%s)" % (self._url, error.code))
         self.is_ended = True
 
 #####################
